<?php
namespace Service;

use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

/**
 * Serviço que pode ser acessado pelo cliente, através do endpoint específico, para buscar as estatísticas
 * de todos os setores em formato JSON.
 * 
 * @author Bernardo Santos <bernardo.santos@teknisa.com>
 * @author Fábio Arruda <fabio.arruda@teknisa.com>
 */ 
class PublicStatisticsService {

	protected $entityManager;
    protected $query;
    
    private $publicStatistics = [];

	public function __construct($entityManager, $query) {
		$this->entityManager = $entityManager;
        $this->query = $query;
	}	

	public function getPublicStatistics(Request $request, Response $response){

        $sectors = $this->entityManager->getConnection()->fetchAll($this->query::GET_KDS_SECTORS, array());
        
        if (!empty($sectors)){

            foreach ($sectors as $currentSector){

                $params = array(
                    ':CDFILIAL' => $currentSector['CDFILIAL'],
                    ':CDSETOR'  => $currentSector['CDSETOR']
                );

                try {
                    $currentSectorStatistics = $this->entityManager->getConnection()->fetchAll($this->query::GET_STATISTICS_FROM_ONE_CLIENT, $params);

                    unset($currentSectorStatistics[0]['QTSETORES']);
                    unset($currentSectorStatistics[0]['SUMQTCONCLUIDO']);
                    unset($currentSectorStatistics[0]['MEDIAKDSDIA']);
                    unset($currentSectorStatistics[0]['SUMQTCONCLUIDOULTHR']);
                    unset($currentSectorStatistics[0]['MEDIAKDSULTHR']);
                    unset($currentSectorStatistics[0]['SUMQTCONCLUIDOHR']);
                    unset($currentSectorStatistics[0]['MEDIAKDSHR']);

                } catch (\Throwable $th) {
                    $response->setError(new Error($th->getMessage(), 500)); 
                }
                
                if (!empty($currentSectorStatistics)){
                    array_push($this->publicStatistics, $currentSectorStatistics);
                }
            }
        }

        $response->addDataSet(new DataSet('statistics', $this->publicStatistics));
	}
	
}